@@ -1,6 +1,7 @@
 import os
 import warnings
 import json
+from multiprocessing import Process
 # noinspection PyUnresolvedReferences
 from collections import defaultdict
 from functools import wraps
@@ -8,14 +9,10 @@ import urllib3
 # noinspection PyUnresolvedReferences
 import random
 from nb_log import LogManager
-from multiprocessing import Process
 # noinspection PyUnresolvedReferences
 from threadpool_executor_shrink_able import BoundedThreadPoolExecutor
 import decorator_libs
 
-from tornado.wsgi import WSGIContainer
-from tornado.httpserver import HTTPServer
-from tornado.ioloop import IOLoop
 from flask import Flask, request, make_response
 
 # noinspection PyUnresolvedReferences
@@ -23,8 +20,8 @@ from proxypool_framework.proxy_pool_config import *
 from proxypool_framework.functions_of_get_https_proxy_from_websites import *
 
 warnings.simplefilter('ignore', category=urllib3.exceptions.InsecureRequestWarning)
-# CHECK_PROXY_VALIDITY_URL = 'https://www.baidu.com/content-search.xml'
-CHECK_PROXY_VALIDITY_URL = 'https://www.baidu.com/favicon.ico'
+CHECK_PROXY_VALIDITY_URL = 'https://www.baidu.com/content-search.xml'
+
 
 def create_app():
     app = Flask(__name__)
@@ -171,14 +168,15 @@ class ProxyCollector:
         else:
             self.logger.warning(f'新拉取的 {self.platform_name} 平台 代理无效')
 
-    def _check_all_new_proxies(self, ):
+    def _check_all_new_proxies(self, pool=None):
         """
         并发检测新代理，有效的入库
         :return:
         """
+        pool = pool or self.pool_for_check_new
         exists_num_in_db = REDIS_CLIENT.zcard(self._redis_key)
         if exists_num_in_db < MAX_NUM_PROXY_IN_DB:
-            self.pool_for_check_new.map(self.__check_a_new_proxy_and_add_to_database,
+            pool.map(self.__check_a_new_proxy_and_add_to_database,
                      [{'https': f'https://{ip}', 'platform': self.platform_name} for ip in
                       self.function_of_get_new_https_proxies_list_from_website(
                           *self._func_args, **self._func_kwargs)])
@@ -216,18 +214,22 @@ class ProxyCollector:
             self._check_all_new_proxies)()
 
 
+def run_flask_app():
+    create_app().run(port=FLASK_PORT, threaded=True)  # 简单的运行起来，一般链接redis使用ip就可以，最好不用接口来获取ip，接口控制10秒才能调用一次要。
+
+
 if __name__ == '__main__':
     """初次运行时候由于redis中没有代理ip做爬取第三方网站的引子，会被免费代理网站反爬，ip在前几分钟内会比较少。之后会增多，耐心等待。
-    
+
     启动方式种类：
     1)
     export PYTHONPATH=/codes/proxypool_framework （指的是你的代码的位置，codes换成你的位置） # 这个原理就不需解释了，不知道PYTHONPATH是什么就太low了。
-    
+
     python proxy_collector.py REDIS_URL=redis:// MAX_NUM_PROXY_IN_DB=500 MAX_SECONDS_MUST_CHECK_AGAIN=12 REQUESTS_TIMEOUT=6 FLASK_PORT=6795 PROXY_KEY_IN_REDIS_DEFAULT=proxy_free
     或者在 proxy_pool_config.py 文件中把配置写好，就不需要命令行来传参了。直接 python proxy_collector.py
-    
+
     2)pycharm中打开此项目，可以直接右键点击run proxy_collector.py
-    
+
     3)pip install proxypool_framework
     python -m proxypool_framework.proxy_collector REDIS_URL=redis:// MAX_NUM_PROXY_IN_DB=500 MAX_SECONDS_MUST_CHECK_AGAIN=12 REQUESTS_TIMEOUT=6 FLASK_PORT=6795 PROXY_KEY_IN_REDIS_DEFAULT=proxy_free
     """
@@ -256,6 +258,6 @@ if __name__ == '__main__':
         ProxyCollector(get_from_jiangxianli, func_kwargs={'p': p}, platform_name='jiangxianli', time_sleep_for_get_new_proxies=time_sleep_for_get_new_proxiesx).work()
 
     """启动api"""
-    http_server = HTTPServer(WSGIContainer(create_app()))
-    http_server.listen(FLASK_PORT)
-    IOLoop.instance().start()
+
+    # run_flask_app()
+    Process(target=run_flask_app).start()  # 主进程里面线程太多了，直接再当前进程启动falsk，访问flask接口响应时间不稳定。这只是简单部署，10秒种请求1次性能足够了。
